@@ -8,11 +8,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use URI qw();
 use URI::QueryParam qw();
@@ -730,7 +730,7 @@ sub do_all {
     $self->remove_empty_query_parameters;
     $self->remove_hostname_prefix;
     $self->remove_empty_query;
-    $self->remove_social_query_parts;
+    $self->remove_social_query_parameters;
 
     return 1;
 }
